function lacticoCCRC
clc, close all

%Condiciones iniciales
t0 = 0; %(h) tiempo inicial
tf = 40; %(h) tiempo final
X0 = 3; %(g/L) biomasa inicial
S0 = 100; %(g/L) sustrato inicial 
AL0 = 0; %(g/L) producto inicial
x0 = [X0; S0; AL0]; %Vector de condiciones iniciales


%   Metodo numerico
[t,x] = ode45(@EDOmodeloloteaclacB,[t0 tf],x0);

%Analisis
plot(t,x(:,1),'g.-')
xlabel('Tiempo (horas)')
ylabel('X,S,P (g/L')
hold on
plot(t,x(:,2),'b.-')
plot(t,x(:,3),'r.-')
legend('X','S','P')
title('Modelo con recirculado')
end

function f=EDOmodeloloteaclacB(~,x)

%Variables de estado

X = x(1);
S = x(2);
AL = x(3);

%Parametros cinticos
mumax = 0.55;    % (h-1) tasa de crecimiento especfica
Ks    = 0.5;     % (g/L)
Km    = 5;       % (g/L) 
Ki    = 41.7;    % (g/L) constante de inhibicin por producto
Kd    = 0.05;    % (h-1) constante de muerte o decaimiento
mmax  = 0.7;     % (h-1) constante de mantenimiento celular
Yxs   = 0.3;     % (g/g) rendimiento biomasa/sustrato
YALs   = 0.85;   % (g/g) rendimiento producto/sustrato
alfa  = 3;
S0 = 100;        %(g/L) sustrato inicial 
AL0 = 0;         %(g/L) producto inicial
D1 = 1;          %(h-1) tasa de alimentacin
D2 = .005;        %(h-1) tasa de purga


%Ecuaciones 

dX = (mumax*(S/(Ks+S))*(1/(1+(AL/Ki)^(alfa)))-Kd)*X;
dS = -(1/Yxs)*(mumax*(S/(Ks+S))*(1/(1+(AL/Ki)^(alfa))))*X-mmax*S/(Km+S);
dAL = (YALs/Yxs)*(mumax*(S/(Ks+S))*(1/(1+(AL/Ki)^(alfa))))*X+mmax*S/(Km+S);


f= [dX, dS, dAL]';


end
